<?xml version="1.0"?>
<xsl:stylesheet version="1.0"
xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
xmlns:fo="http://www.w3.org/1999/XSL/Format"
>

<!--  <xsl:import href="/usr/local/Cellar/docbook-xsl/1.79.1/docbook-xsl/fo/docbook.xsl"/> -->
<xsl:import href="http://docbook.sourceforge.net/release/xsl/current/fo/docbook.xsl" />
  
<!--
  Convert last-page-marker into an FO block with id of END-OF-DOCUMENT.
  This is used later to support the "page X of Y" numbering.
-->
<xsl:template match="processing-instruction('last-page-marker')">
    <fo:block id="END-OF-DOCUMENT"/>
</xsl:template>

<!-- Consecutively number pages from 1 to last page using arabic numerals -->
<xsl:template name="initial.page.number">auto-odd</xsl:template>
<xsl:template name="page.number.format">1</xsl:template>

<!--
  Turn on section numbering and make it include chapter numbers in section
  numbers
-->
<xsl:param name="section.autolabel">1</xsl:param>
<xsl:param name="section.label.includes.component.label" select="1"/>

<!-- Some sublists are using roman numerials and they need more space -->
<!-- <xsl:param name="itemizedlist.label.width">2.0em</xsl:param> -->

<!-- <xsl:param name="monospace.verbatim.font.width">0.20em</xsl:param> -->
<xsl:param name="shade.verbatim" select="1"/>

<!-- Customize footer.column.widths to make center portion much wider than the sides -->
<xsl:param name="footer.column.widths">1 48 1</xsl:param>
<!--
  I keep getting long itemizedlist elements overflowing the footer.  Below is
  an attempt to mostly avoid that, but doesn't always work.  I probably need
  to create a non-WD XML that triggers the same overflow issue so I can post
  it on the FOP forum.
-->
<xsl:param name="body.margin.bottom">0.8in</xsl:param>


<!-- Customize header.content to make page numbering be "page X of Y" -->
<xsl:template name="header.content">
  <xsl:param name="pageclass" select="''"/>
  <xsl:param name="sequence" select="''"/>
  <xsl:param name="position" select="''"/>
  <xsl:param name="gentext-key" select="''"/>

<!--
  <fo:block>
    <xsl:value-of select="$pageclass"/>
    <xsl:text>, </xsl:text>
    <xsl:value-of select="$sequence"/>
    <xsl:text>, </xsl:text>
    <xsl:value-of select="$position"/>
    <xsl:text>, </xsl:text>
    <xsl:value-of select="$gentext-key"/>
  </fo:block>
-->

  <fo:block>

    <!-- sequence can be odd, even, first, blank -->
    <!-- position can be left, center, right -->
    <xsl:choose>
      <xsl:when test="$sequence = 'blank'">
        <!-- nothing -->
      </xsl:when>

      <xsl:when test="$position='left'">
        <!-- Same for odd, even, empty, and blank sequences -->
        <xsl:call-template name="draft.text"/>
      </xsl:when>

      <xsl:when test="$position='center'">
        <xsl:apply-templates select="(/book/bookinfo/title)[1]" mode="title.markup"/>
      </xsl:when>

      <!-- MW: this is only part of this template I actually customized -->
      <xsl:when test="$double.sided = 0 and $position='right'">
        <xsl:text>Page </xsl:text>  
        <fo:page-number/>
        <xsl:text> of </xsl:text>
        <fo:page-number-citation ref-id="END-OF-DOCUMENT"/>
      </xsl:when>

      <xsl:when test="$position='center'">
        <!-- nothing for empty and blank sequences -->
      </xsl:when>

      <xsl:when test="$position='right'">
        <!-- Same for odd, even, empty, and blank sequences -->
        <xsl:call-template name="draft.text"/>
      </xsl:when>

      <xsl:when test="$sequence = 'first'">
        <!-- nothing for first pages -->
      </xsl:when>

      <xsl:when test="$sequence = 'blank'">
        <!-- nothing for blank pages -->
      </xsl:when>
    </xsl:choose>
  </fo:block>
</xsl:template>

<!--
  Customize footer.content to remove the page numbering since we do that
  in the header instead.  Also insert the WD confidential text in the center
  portion of the footer on each page.
-->
<xsl:template name="footer.content">
  <xsl:param name="pageclass" select="''"/>
  <xsl:param name="sequence" select="''"/>
  <xsl:param name="position" select="''"/>
  <xsl:param name="gentext-key" select="''"/>

<!--
  <fo:block>
    <xsl:value-of select="$pageclass"/>
    <xsl:text>, </xsl:text>
    <xsl:value-of select="$sequence"/>
    <xsl:text>, </xsl:text>
    <xsl:value-of select="$position"/>
    <xsl:text>, </xsl:text>
    <xsl:value-of select="$gentext-key"/>
  </fo:block>
-->

  <fo:block>
    <!-- pageclass can be front, body, back -->
    <!-- sequence can be odd, even, first, blank -->
    <!-- position can be left, center, right -->
    <xsl:choose>
      <xsl:when test="$double.sided = 0 and $position='center'">
        <xsl:text>This footer text would normally say this document is confidential and
you can't give it to anybody and nobody gets to read it and yadda, yadda, yadda.
For this example it is about the same length to show the overlflow.</xsl:text>
      </xsl:when>
      <xsl:otherwise>
        <!-- nop -->
      </xsl:otherwise>
    </xsl:choose>
  </fo:block>
</xsl:template>

</xsl:stylesheet>